'****************************************************************
'*  Name    : Amicus18_25K22.inc                                *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2016 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 05/02/2016                                        *
'*  Version : 1.2 04/10/2018                                    *
'*  Notes   :                                                   *
'*          :                                                   *
'****************************************************************
'
$ifndef _AMICUS18_INC
$define _AMICUS18_INC
'/------------------------------------------------------------------------------
' Header file for use with the Amicus18 board
'
    Device = 18F25K22

    $if PLL_ConfigFuses = On
        Declare Xtal = 64
    $else
        Declare Xtal = 16
    $endif        
        
    $ifdef __WatchDog_ON
        #define Watchdog_req 1
    $endif
    $ifdef __TestInterruptsEnabled
        #define __INTERRUPTS_ENABLED 1
    $endif
'/==============================================================================
$ifndef __ExtraPICParameters
$define __ExtraPICParameters
$if _device = _18F25K22
    $define __DEVICE_ID 682
    $define __DEVICE_NAME "PIC18F25K22"

    $ifndef _erase
    $define _erase 64
    $endif
$endif

$endif
'/==============================================================================
    Declare Optimiser_Level = 3
    Declare Dead_Code_Remove = On
'/==============================================================================
$if _xtal = 64
'Calculated Baudrate = 9598 @ Xtal 64MHz, Error = -0,02%
    Declare Hserial_RCSTA  = 144            ' Enable continuous receive 
    Declare Hserial_TXSTA  = 36             ' Enable transmit, BRGH = 1
    Declare Hserial_Clear  = On             ' Clear overflow automatically
    Declare Hserial_SPBRG  = 130            ' Baud Rate Generator Low Byte Value
    SPBRGH         = $06                    ' Baud Rate Generator High Byte Value
    BAUDCON.3      = 1                      ' Enable the 16 bit Baud Rate Generator
'-------------------------------------------------------------------------------
$else
'-------------------------------------------------------------------------------
    Declare Hserial_Baud = 9600             ' Set baud rate to 9600
    Declare Hserial_RCSTA = 144             ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = 32              ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On              ' Enable Error clearing on received characters
$endif
'/==============================================================================
Config_Start
$if PLL_ConfigFuses = On
    $ifdef _InternalOSC_
        $if (_xtal = 16) Or (_xtal = 32) Or (_xtal = 64)
            $ifdef _CLKOUT_Function_
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = On"
        $endif
        PRICLKEN = OFF	;Primary clock can be disabled by software.
    $else
        $if (_xtal >= 10) And (_xtal <= 64)
        FOSC = HSMP	    ;HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)(Xtal piece 2,5-16 MHz)
        $else
            $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = On"
        $endif
        PRICLKEN = On	;Primary clock enabled.
    $endif
    PLLCFG = On	        ;Oscillator multiplied by 4
$else
    $ifdef _InternalOSC_
        $if (_xtal = 16)
            $ifdef _CLKOUT_Function_
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = OFF"
        $endif
        PRICLKEN = OFF	;Primary clock can be disabled by software.
    $else
'        $if (_xtal >= 10) And (_xtal < 16)
        $if (_xtal >= 10) And (_xtal <= 16)
        FOSC = HSMP	        ;HS oscillator (medium power 4-16 MHz)
        $else
'            $if (_xtal >= 16) And (_xtal <= 25)
            $if (_xtal > 16) And (_xtal <= 25)
            FOSC = HSHP     ; HS oscillator (high power > 16 MHz)
            $else
                $if (_xtal > 25) And (_xtal <= 64)   
                FOSC = ECHP ; EC oscillator, CLKOUT function on OSC2 (high power, >16 MHz)
                $else
                    $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = OFF"
                $endif
            $endif
        $endif
        PRICLKEN = On	;Primary clock enabled.
    $endif
    PLLCFG = OFF	    ;Oscillator multiplied by 1
$endif
    FCMEN = Off	     ;Fail-Safe Clock Monitor disabled
    IESO = OFF	     ;Oscillator Switchover mode disabled
    PWRTEN = On	     ;Power up timer enabled
    BOREN = On	     ;Brown-out Reset enabled and controlled by software (SBOREN is enabled)
    BORV = 190	     ;VBOR set to 1.90 V nominal
    WDTEN = SWON	  ; WDT is controlled by SWDTEN Bit of the WDTCON register
    WDTPS = 512	        ;1:512
    CCP2MX = PORTC1	;CCP2 input/output is multiplexed with RC1
    PBADEN = On    ' PORTB<4:0> pins are configured as analog I/O on Reset
    CCP3MX = PORTB5	;P3A/CCP3 input/output is multiplexed with RB5
    HFOFST = Off    ' The system clock is held off until the HF-INTOSC is stable.
    T3CMX = PORTC0	;T3CKI is on RC0
    P2BMX = PORTB5	;P2B is on RB5
    MCLRE = EXTMCLR	;MCLR pin enabled, RE3 input pin disabled
    STVREN = On	    ;Stack full/underflow will cause Reset
    LVP = OFF	    ;Single-Supply ICSP disabled
    XINST = OFF	    ;Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    Debug = OFF	    ; Background debugger disabled RB6 and RB7 configured as general purpose I/O pins
    Cp0 = OFF	;Block 0 (000800-001FFFh) not code-protected
    CP1 = OFF	;Block 1 (002000-003FFFh) not code-protected
    CP2 = OFF	;Block 2 (004000-005FFFh) not code-protected
    CP3 = OFF	;Block 3 (006000-007FFFh) not code-protected
    CPB = OFF	;Boot block (000000-0007FFh) not code-protected
    CPD = On	;Data EEPROM code-protected
    WRT0 = OFF	;Block 0 (000800-001FFFh) not write-protected
    WRT1 = OFF	;Block 1 (002000-003FFFh) not write-protected
    WRT2 = OFF	;Block 2 (004000-005FFFh) not write-protected
    WRT3 = OFF	;Block 3 (006000-007FFFh) not write-protected
    WRTC = On	;Configuration registers (300000-3000FFh) write-protected
    WRTB = OFF	;Boot Block (000000-0007FFh) not write-protected
    WRTD = OFF	;Data EEPROM not write-protected
    EBTR0 = OFF	;Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
    EBTR1 = OFF	;Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
    EBTR2 = OFF	;Block 2 (004000-005FFFh) not protected from table reads executed in other blocks
    EBTR3 = OFF	;Block 3 (006000-007FFFh) not protected from table reads executed in other blocks
    EBTRB = OFF	;Boot Block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End
'/==============================================================================
    Symbol ESC = $1B    ' Escape
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol SPACE = $20
    Symbol Home = 1
    Symbol Bell = 7
    Symbol BkSp = 8
    Symbol Tab = 9

    $ifndef CR
        $define CR 13
    $endif
    $ifndef LF
        $define LF 10
    $endif

    $ifndef False
        $define False 0
    $endif
    $ifndef True
        $define True 1
    $endif
'/==============================================================================
$ifdef _CheckRCONBits_
    '/ Control of the RCON register.
    Dim RCONBits As Byte System
    $define __RCONBitsHeader
    RCONBits = RCON
$endif
'/==============================================================================
    $define __SWDTEN_CFG   
    #ifdef Watchdog_req
    Clrwdt
    WDTCONBits_SWDTEN = 1
    #else
    WDTCONBits_SWDTEN = 0    
    #endif
'/==============================================================================
'/ Declare All Digital.
    ANSELA = 0
    ANSELB = 0
    ANSELC = 0
    ADCON0 = 0
    CM1CON0 = 0
    CM2CON0 = 0
    CM2CON1 = 0
'/------------------------------------------------------------------------------
$endif
'/==============================================================================


