$ifndef _PROTON18_INC
$define _PROTON18_INC
' Header file for the Proton Development Board
' Using a 18F452 Device with a 24MHz Oscillator
'
    Device = 18F452
    Declare Xtal = 24

    Declare LCD_DTPin = PORTD.4
    Declare LCD_RSPin = PORTE.0
    Declare LCD_ENPin = PORTE.1
    Declare LCD_Interface = 4
    Declare LCD_Lines = 2
    Declare LCD_Type = 0
    Declare LCD_CommandUs = 2000
    Declare LCD_DataUs = 50

    Declare SCL_Pin = PORTC.3
    Declare SDA_Pin = PORTC.4

    Declare Serial_Baud = 9600
    Declare RsOut_Pin = PORTC.6
    Declare RsOut_Mode = 0
    Declare RsOut_Pace = 1000
    Declare RsIn_Pin = PORTC.7
    Declare RsIn_Mode = 0

    Declare Hserial_Baud = 9600                 ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000           ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100100           ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On                  ' Enable Error clearing on received characters

    Declare Keypad_Port = PORTB

    Declare CCP1_Pin = PORTC.2
    Declare CCP2_Pin = PORTC.1

    Symbol T300 = 3313
    Symbol N300 = 3313 + $4000
    Symbol T600 = 1646
    Symbol N600 = 1646 + $4000
    Symbol T1200 = 813
    Symbol N1200 = 813 + $4000
    Symbol T2400 = 396
    Symbol N2400 = 396 + $4000
    Symbol T4800 = 188
    Symbol N4800 = 188 + $4000
    Symbol T9600 = 84
    Symbol N9600 = 84 + $4000

    Symbol OT2400 = 396 + $8000                 ' Open True
    Symbol OT1200 = 813 + $8000                 ' Open True
    Symbol OT9600 = 84 + $8000                  ' Open True
    Symbol OT300 = 3313 + $8000                 ' Open True

    Symbol ON2400 = 396 + $4000 + $8000         ' Open Inverted
    Symbol ON1200 = 813 + $4000 + $8000         ' Open Inverted
    Symbol ON9600 = 84 + $4000 + $8000          ' Open Inverted
    Symbol ON300 = 3313 + $4000 + $8000         ' Open Inverted
'/==============================================================================
Config_Start
$if PLL_ConfigFuses = On
    $if (_xtal >= 10) And (_xtal <= 40)
    OSC = HSPLL	;HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC)(Xtal piece 2,5-10 MHz)
    $else
        $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = On"
    $endif
$else
    $if (_xtal >= 10) And (_xtal <= 25)
    OSC = HS	    ;HS oscillator PLL disabled  (medium power 4-20 MHz) (Xtal piece 10-32 MHz)
    $else
        $if (_xtal > 25) And (_xtal <= 40)
            $ifdef _CLKOUT_Function_
            OSC = EC     ; Exterior EC oscillator, CLKOUT function On RA6 
            $else
            OSC = ECIO   ; Exterior EC oscillator, port function on RA6 
            $endif
        $else
            $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = OFF"
        $endif
   $endif
$endif
    OSCS = OFF	;Oscillator system clock switch option is disabled (main oscillator is source)
    PWRT = On	;PWRT enabled
    BOR = On	;Brown-out Reset enabled
    BORV = 20	;VBOR set to 2.0V
    WDT = OFF	;WDT disabled (control is placed on the SWDTEN bit)
    WDTPS = 128	;1:128
    CCP2MUX = On	;CCP2 input/output is multiplexed with RC1
    STVR = On	;Stack Full/Underflow will cause RESET
    LVP = OFF	;Low Voltage ICSP disabled
    Debug = OFF	;Background Debugger disabled. RB6 and RB7 configured as general purpose I/O pins.
    Cp0 = OFF	;Block 0 (000200-001FFFh) not code protected
    CP1 = OFF	;Block 1 (002000-003FFFh) not code protected
    CP2 = OFF	;Block 2 (004000-005FFFh) not code protected
    CP3 = OFF	;Block 3 (006000-007FFFh) not code protected
    CPB = OFF	;Boot Block (000000-0001FFh) not code protected
    CPD = OFF	;Data EEPROM not code protected
    WRT0 = OFF	;Block 0 (000200-001FFFh) not write protected
    WRT1 = OFF	;Block 1 (002000-003FFFh) not write protected
    WRT2 = OFF	;Block 2 (004000-005FFFh) not write protected
    WRT3 = OFF	;Block 3 (006000-007FFFh) not write protected
    WRTC = On	;Configuration registers (300000-3000FFh) write protected
    WRTB = OFF	;Boot Block (000000-0001FFh) not write protected
    WRTD = OFF	;Data EEPROM not write protected
    EBTR0 = OFF	;Block 0 (000200-001FFFh) not protected from Table Reads executed in other blocks
    EBTR1 = OFF	;Block 1 (002000-003FFFh) not protected from Table Reads executed in other blocks
    EBTR2 = OFF	;Block 2 (004000-005FFFh) not protected from Table Reads executed in other blocks
    EBTR3 = OFF	;Block 3 (006000-007FFFh) not protected from Table Reads executed in other blocks
    EBTRB = OFF	;Boot Block (000000-0001FFh) not protected from Table Reads executed in other blocks
Config_End
'/==============================================================================
$ifndef __ExtraPICParameters
$define __ExtraPICParameters
$if _device = _18F452
    $define __DEVICE_ID 33
    $define __DEVICE_NAME "PIC18F452"

    $ifndef _erase
    $define _erase 64
    $endif
$endif

$endif
'/==============================================================================
'ASCII characters  
    Symbol ESC = $1B    ' Escape
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol SPACE = $20
    Symbol Home = 1
    Symbol Bell = 7
    Symbol BkSp = 8
    Symbol Tab = 9

    $ifndef CR
    $define CR 13
    $endif
    $ifndef LF
    $define LF 10
    $endif

    $ifndef False
    $define False 0
    $endif
    $ifndef True
    $define True 1
    $endif

'/==============================================================================
$ifdef _CheckRCONBits_
    '/ Control of the RCON register.
    Dim RCONBits As Byte System
    $define __RCONBitsHeader
    RCONBits = RCON
$endif
'/==============================================================================
    $define __SWDTEN_CFG   
    #ifdef Watchdog_req
    Clrwdt
    WDTCONBits_SWDTEN = 1
    #else
    WDTCONBits_SWDTEN = 0    
    #endif
'/==============================================================================
    Declare All_Digital = True                  ' Set PORTA and PORTE to all digital
$endif
'/------------------------------------------------------------------------------


