$ifndef _PROTON18_INC
$define _PROTON18_INC
' Header file for the Proton Development Board
' Using a 18F45K20 Device with a 64MHz Oscillator
'
    Device = 18F45K20
    Declare Xtal = 64

    Declare LCD_DTPin = PORTD.4
    Declare LCD_RSPin = PORTE.0
    Declare LCD_ENPin = PORTE.1
    Declare LCD_Interface = 4
    Declare LCD_Lines = 2
    Declare LCD_Type = 0
    Declare LCD_CommandUs = 2000
    Declare LCD_DataUs = 50

    Declare SCL_Pin = PORTB.1
    Declare SDA_Pin = PORTB.0

    Declare Serial_Baud = 9600
    Declare RsOut_Pin = PORTC.6
    Declare RsOut_Mode = 0
    Declare RsOut_Pace = 1000
    Declare RsIn_Pin = PORTC.7
    Declare RsIn_Mode = 0

    Declare Hserial_Baud = 9600                     ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000               ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100000               ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = On                      ' Enable Error clearing on received characters

    Declare Keypad_Port = PORTB

    Declare CCP1_Pin = PORTC.2
    Declare CCP2_Pin = PORTC.1

    Symbol T300 = 3313
    Symbol N300 = 3313 + $4000
    Symbol T600 = 1646
    Symbol N600 = 1646 + $4000
    Symbol T1200 = 813
    Symbol N1200 = 813 + $4000
    Symbol T2400 = 396
    Symbol N2400 = 396 + $4000
    Symbol T4800 = 188
    Symbol N4800 = 188 + $4000
    Symbol T9600 = 84
    Symbol N9600 = 84 + $4000

    Symbol OT2400 = 396 + $8000                     ' Open True
    Symbol OT1200 = 813 + $8000                     ' Open True
    Symbol OT9600 = 84 + $8000                      ' Open True
    Symbol OT300 = 3313 + $8000                     ' Open True

    Symbol ON2400 = 396 + $4000 + $8000             ' Open Inverted
    Symbol ON1200 = 813 + $4000 + $8000             ' Open Inverted
    Symbol ON9600 = 84 + $4000 + $8000              ' Open Inverted
    Symbol ON300 = 3313 + $4000 + $8000             ' Open Inverted
'/==============================================================================
Config_Start
$if PLL_ConfigFuses = On
    $ifdef _InternalOSC_
        $if (_xtal = 32) Or (_xtal = 64)
            $ifdef CLKOUT_Function
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = On"
        $endif
    $else
        $if (_xtal >= 10) And (_xtal <= 80)
        FOSC = HSPLL	;HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)(Xtal piece 2,5 -> 20 MHz)
        $else
            $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = On"
        $endif
    $endif
$else
    $ifdef _InternalOSC_
        $if (_xtal = 16)
            $ifdef CLKOUT_Function
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = OFF"
        $endif
    $else
        $if (_xtal >= 10) And (_xtal <= 25)
        FOSC = HS	    ;HS oscillator PLL disabled  (medium power 4-20 MHz) (Xtal piece 10 -> 25 MHz)
        $else
            $if (_xtal > 25) And (_xtal <= 80)
                $ifdef CLKOUT_Function
                FOSC = EC       ; External EC oscillator, CLKOUT function in RA6      
                $else
                FOSC = ECIO6    ; External EC oscillator, port function on RA6
                $endif
            $else
                $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = OFF"
            $endif
       $endif
    $endif
$endif
    FCMEN = OFF	;Fail-Safe Clock Monitor disabled
    IESO = OFF	;Oscillator Switchover mode disabled
    PWRT = On	;PWRT enabled
    BOREN = On	;Brown-out Reset enabled and controlled by software (SBOREN is enabled)
    BORV = 22	;VBOR set to 2.2 V nominal
    WDTEN = OFF	;WDT is controlled by SWDTEN bit of the WDTCON register
    WDTPS = 512	    ;1:512
    CCP2MX = PORTC	;CCP2 input/output is multiplexed with RC1
    PBADEN = On	;PORTB<4:0> pins are configured as analog input channels on Reset
    LPT1OSC = OFF	;Timer1 configured for higher power operation
    HFOFST = OFF	;The system clock is held off until the HFINTOSC is stable.
    MCLRE = On	;MCLR pin enabled; RE3 input pin disabled
    STVREN = On	;Stack full/underflow will cause Reset
    LVP = OFF	;Single-Supply ICSP disabled
    XINST = OFF	;Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    Debug = OFF	;Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
    Cp0 = OFF	;Block 0 (000800-001FFFh) not code-protected
    CP1 = OFF	;Block 1 (002000-003FFFh) not code-protected
    CP2 = OFF	;Block 2 (004000-005FFFh) not code-protected
    CP3 = OFF	;Block 3 (006000-007FFFh) not code-protected
    CPB = OFF	;Boot block (000000-0007FFh) not code-protected
    CPD = On	;Data EEPROM code-protected
    WRT0 = OFF	;Block 0 (000800-001FFFh) not write-protected
    WRT1 = OFF	;Block 1 (002000-003FFFh) not write-protected
    WRT2 = OFF	;Block 2 (004000-005FFFh) not write-protected
    WRT3 = OFF	;Block 3 (006000-007FFFh) not write-protected
    WRTC = On	;Configuration registers (300000-3000FFh) write-protected
    WRTB = OFF	;Boot Block (000000-0007FFh) not write-protected
    WRTD = OFF	;Data EEPROM not write-protected
    EBTR0 = OFF	;Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
    EBTR1 = OFF	;Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
    EBTR2 = OFF	;Block 2 (004000-005FFFh) not protected from table reads executed in other blocks
    EBTR3 = OFF	;Block 3 (006000-007FFFh) not protected from table reads executed in other blocks
    EBTRB = OFF	;Boot Block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End
'/==============================================================================
$ifndef __ExtraPICParameters
$define __ExtraPICParameters
$if _device = _18F45K20
    $define __DEVICE_ID 258
    $define __DEVICE_NAME "PIC18F45K20"
    ' Read the Datasheet to know the erase block value.
    $ifndef _erase
    $define _erase 64
    $endif
$endif

$endif
'/==============================================================================
'ASCII characters  
    Symbol ESC = $1B    ' Escape
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol SPACE = $20
    Symbol Home = 1
    Symbol Bell = 7
    Symbol BkSp = 8
    Symbol Tab = 9

    $ifndef CR
    $define CR 13
    $endif
    $ifndef LF
    $define LF 10
    $endif

    $ifndef False
    $define False 0
    $endif
    $ifndef True
    $define True 1
    $endif

'/==============================================================================
$ifdef _CheckRCONBits_
    '/ Control of the RCON register.
    Dim RCONBits As Byte System
    $define __RCONBitsHeader
    RCONBits = RCON
$endif
'/==============================================================================
    $define __SWDTEN_CFG   
    #ifdef Watchdog_req
    Clrwdt
    WDTCONBits_SWDTEN = 1
    #else
    WDTCONBits_SWDTEN = 0    
    #endif
'/==============================================================================
    Declare All_Digital = True          ' Set PORTA and PORTE to all digital
$endif
'/------------------------------------------------------------------------------


