'****************************************************************
'*  Name    : Proton18_46K20.inc                                *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2016 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 04/10/2018                                        *
'*  Version : 1.0                                               *
'*          :                                                   *
'****************************************************************
'
$ifndef _PROTON18_INC
$define _PROTON18_INC
'
' Header file for use with the Amicus18 board
'
    Device = 18F46K20

    $if PLL_ConfigFuses = On
        Declare Xtal = 64
    $else
        Declare Xtal = 16
    $endif     

    $ifdef __WatchDog_ON
    #define Watchdog_req 1
    $endif
    $ifdef __TestInterruptsEnabled
    #define __INTERRUPTS_ENABLED 1
    $endif
'/==============================================================================
$ifndef __ExtraPICParameters
$define __ExtraPICParameters
$if _device = _18F46K20
    $define __DEVICE_ID 256
    $define __DEVICE_NAME "PIC18F46K20"

    $ifndef _erase
    $define _erase 64
    $endif
$endif

$endif
'/==============================================================================
    Declare Optimiser_Level = 3
    Declare Dead_Code_Remove = On
'/==============================================================================
$if _xtal = 64
'Calculated Baudrate = 9598 @ Xtal 64MHz, Error = -0,02%
    Declare Hserial_RCSTA  = 144        ' Enable continuous receive 
    Declare Hserial_TXSTA  = 36         ' Enable transmit, BRGH = 1
    Declare Hserial_Clear  = On         ' Clear overflow automatically
    Declare Hserial_SPBRG  = $82        ' Baud Rate Generator Low Byte Value
    SPBRGH         = $06                ' Baud Rate Generator High Byte Value
    BAUDCON.3      = 1                  ' Enable the 16 bit Baud Rate Generator
'-------------------------------------------------------------------------------
$else
'-------------------------------------------------------------------------------
'    Declare Hserial_Baud = 38400                 ' Set baud rate to 9600
    Declare Hserial_Baud = 9600                 ' Set baud rate to 9600
    Declare Hserial_RCSTA = %10010000           ' Enable serial port and continuous receive
    Declare Hserial_TXSTA = %00100000           ' Enable transmit and asynchronous mode
    Declare Hserial_Clear = 1                   ' Enable Error clearing on received characters
$endif
'-------------------------------------------------------------------------------
Config_Start
$if PLL_ConfigFuses = On
    $ifdef _InternalOSC_
        $if (_xtal = 32) Or (_xtal = 64)
            $ifdef CLKOUT_Function
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = On"
        $endif
    $else
        $if (_xtal >= 10) And (_xtal <= 80)
        FOSC = HSPLL	;HS oscillator, PLL enabled (Clock Frequency = 4 x FOSC1)(Xtal piece 2,5 -> 20 MHz)
        $else
            $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = On"
        $endif
    $endif
$else
    $ifdef _InternalOSC_
        $if (_xtal = 16)
            $ifdef CLKOUT_Function
            FOSC = INTIO7	;Internal oscillator block, CLKOUT in RA6, port function on RA7.        
            $else
            FOSC = INTIO67	;Internal oscillator block, port function on RA6 and RA7.
            $endif
        $else
            $error "Error in (Declare Xtal) with internal oscillator & PLL_ConfigFuses = OFF"
        $endif
    $else
        $if (_xtal >= 10) And (_xtal <= 25)
        FOSC = HS	    ;HS oscillator PLL disabled  (medium power 4-20 MHz) (Xtal piece 10 -> 25 MHz)
        $else
            $if (_xtal > 25) And (_xtal <= 80)
                $ifdef CLKOUT_Function
                FOSC = EC       ; External EC oscillator, CLKOUT function in RA6      
                $else
                FOSC = ECIO6    ; External EC oscillator, port function on RA6
                $endif
            $else
                $error "Error in (Declare Xtal) with external Xtal & PLL_ConfigFuses = OFF"
            $endif
       $endif
    $endif
$endif
    FCMEN = OFF	;Fail-Safe Clock Monitor disabled
    IESO = OFF	;Oscillator Switchover mode disabled
    PWRT = On	;PWRT enabled
    BOREN = On	;Brown-out Reset enabled and controlled by software (SBOREN is enabled)
    BORV = 22	;VBOR set to 2.2 V nominal
    WDTEN = OFF	    ;WDT is controlled by SWDTEN bit of the WDTCON register
    WDTPS = 1024	    ;1:1024
    CCP2MX = PORTC	;CCP2 input/output is multiplexed with RC1
    PBADEN = On	    ;PORTB<4:0> pins are configured as analog input channels on Reset
    LPT1OSC = OFF	;Timer1 configured for higher power operation
    HFOFST = OFF	;The system clock is held off until the HFINTOSC is stable.
    MCLRE = On	;MCLR pin enabled; RE3 input pin disabled
    STVREN = On	;Stack full/underflow will cause Reset
    LVP = OFF	;Single-Supply ICSP disabled
    XINST = OFF	;Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    Debug = OFF	;Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
    Cp0 = OFF	;Block 0 (000800-003FFFh) not code-protected
    CP1 = OFF	;Block 1 (004000-007FFFh) not code-protected
    CP2 = OFF	;Block 2 (008000-00BFFFh) not code-protected
    CP3 = OFF	;Block 3 (00C000-00FFFFh) not code-protected
    CPB = OFF	;Boot block (000000-0007FFh) not code-protected
    CPD = On	;Data EEPROM code-protected
    WRT0 = OFF	;Block 0 (000800-003FFFh) not write-protected
    WRT1 = OFF	;Block 1 (004000-007FFFh) not write-protected
    WRT2 = OFF	;Block 2 (008000-00BFFFh) not write-protected
    WRT3 = OFF	;Block 3 (00C000h-00FFFFh) not write-protected
    WRTC = On	;Configuration registers (300000-3000FFh) write-protected
    WRTB = OFF	;Boot Block (000000-0007FFh) not write-protected
    WRTD = OFF	;Data EEPROM not write-protected
    EBTR0 = OFF	;Block 0 (000800-003FFFh) not protected from table reads executed in other blocks
    EBTR1 = OFF	;Block 1 (004000-007FFFh) not protected from table reads executed in other blocks
    EBTR2 = OFF	;Block 2 (008000-00BFFFh) not protected from table reads executed in other blocks
    EBTR3 = OFF	;Block 3 (00C000-00FFFFh) not protected from table reads executed in other blocks
    EBTRB = OFF	;Boot Block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End

    Symbol BS = 08      ' Backspace
    Symbol ESC = $1B    ' Escape
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol SPACE = $20

    $ifndef CR
    $define CR 13
    $endif
    $ifndef LF
    $define LF 10
    $endif

    $ifndef False
    $define False 0
    $endif
    $ifndef True
    $define True 1
    $endif
'/==============================================================================
$ifdef _CheckRCONBits_
    '/ Control of the RCON register.
    Dim RCONBits As Byte System
    $define __RCONBitsHeader
    RCONBits = RCON
$endif
'/==============================================================================
    $define __SWDTEN_CFG   
    #ifdef Watchdog_req
    Clrwdt
    WDTCONBits_SWDTEN = 1
    #else
    WDTCONBits_SWDTEN = 0    
    #endif
'/==============================================================================
    ANSEL = 0
    ANSELH = 0
    ADCON0 = 0
    CM1CON0 = 0
    CM2CON0 = 0
'/==============================================================================
$endif
'/==============================================================================

