'****************************************************************
'*  Name    : MeasurePeriod_Teo.BAS                             *
'*  Author  : [Alberto Freixanet]                               *
'*  Notice  : Copyright (c) 2018 [AFreixanet]                   *
'*          : All Rights Reserved                               *
'*  Date    : 03/10/2018                                        *
'*  Version : 1.0                                               *
'*  Notes   : The Frequency tested is 5Hz to 10 000Hz.          *
'*            Tested with Proteus V8.20                         *
'*            All include files are in the INC folder           *
'****************************************************************

'/ Include files needed:
'/ Amicus18_25K22.Inc
'/ Tips_and_Tricks_V14.Inc
'/ DeclareLocalVars.Inc
'/ PICslist.inc

'/==============================================================================
'/ Declares Options
    $define PLL_ConfigFuses On
    $define __WatchDog_ON
    $define _CheckRCONBits_
'    $define __TestInterruptsEnabled
'/------------------------------------------------------------------------------
    '/ Create your own path in the Hard disk D:\MyIncFiles. 
    Include "D:\MyIncFiles\Amicus18_25K22.inc"
'/==============================================================================
    Declare Float_Display_Type = Fast
    Declare Float_Rounding = On
    Declare Watchdog = OFF

    Declare LCD_DTPin = PORTB.4
    Declare LCD_RSPin = PORTC.0
    Declare LCD_ENPin = PORTC.1
    Declare LCD_Interface = 4
    Declare LCD_Lines = 2
    Declare LCD_Type = 0
    Declare LCD_CommandUs = 2000
    Declare LCD_DataUs = 50

'/==============================================================================
'/ Declares Options
    $define _Print_Float
    $define _CLL_
    $define _MeasurePeriod_
    $define __MEASURE_CODE_
'/------------------------------------------------------------------------------
    '/ Create your own path in the Hard disk D:\MyIncFiles. 
    Include "D:\MyIncFiles\Tips_and_Tricks_V16.inc"
'/==============================================================================
    Dim MyByteVar As Byte
    Dim MyWordVar As Word
    Dim MyDwordVar As Dword
    Dim Capture As Dword
    Dim NbSamples As Word    
    Dim MyFloatVar As Float

    Dim Frequency As Word
    Dim FrequencyFlt As Float
    Dim FreqDecimals As Word    
    Dim MyLoop As Byte
    Dim Oscilloscope2 As LATC.3
'/==============================================================================        
    GoTo OverMacro       

  
'/==============================================================================
OverMacro:
MAIN:
'    HRSOut_RCON()   '/ Print states of Reset. (option)
    DelayMS 500
    Cls
    Low Oscilloscope2
'/------------------------------------------------------------------------------
'/ This code displayes the frequencies from 5Hz To 5000Hz measuring the period.
'/ An edge detector is included and filters the input below 5 Hz to avoid the
'/ code hangs when there is not a signal.
'/ The FOSC/4 frequency instruction is used to calculate the frequency.
'/ Thank to the formula it is independent of FOSC. 
'/ For better resolution use the FOSC = 64Mhz (PIC18FxxKxx)
'/
'/ See the MeasurePeriod folder to read the code.
'/ The macro is in Tips_and_Trick_V14.inc file.
'/
'/ NOTE: Print the decimals with 1,2 or 3 digits. Print Dec1, Dec2, Dec3.

'/ Read the LCD.
'/ ??     => Number of Loops or measures.
'/ S???   => Number of reading samples.
'/ C????? => Number of clocks capture.
'/ FI:??? => Frequency with Integer.
'/ FL:??? => Frequency with Float.

    HRSOut "TEST MEASURE PERIOD:",CR
    HRSOut "MeasurePeriod_Teo.BAS:",CR,CR

    HRSOut "READ ON THE LCD",CR
    HRSOut "??         => Number of Loops",CR
    HRSOut "S???       => Number of Reading Samples",CR
    HRSOut "C???????   => Number of Clocks Capture",CR
    HRSOut "FI: ???? => Frequency with Integers calculations with 1,2,3 decimals",CR
    HRSOut "FL: ???? => Frequency with Floats calculations with 1,2,3 decimals",CR,CR

    $ifdef _Print_Float
    HRSOut "Using Float:",CR 
    HRSOut "FrequencyFlt/[Float] = MeasureFreq(Lower Frequency[Number], Number of Decimals[Number])",CR   
    $else
    HRSOut "Using Integers:",CR
    HRSOut "Frequency/[Word] = MeasureFreq(Lower Frequency[Number], FreqInDecimals[Word], Number of Decimals[Number])",CR
    $endif
    HRSOut "Configured with 2 decimals.",CR
    
    NbSamples = 0
    MyLoop = 0
    Do
        $ifdef _Print_Float
            '/ Float Result.
            Set Oscilloscope2
            FrequencyFlt = MeasureFreq(20,2)    '/ Frequency in Float. Minimum 20Hz, 2 decimals
            Clear Oscilloscope2
            $ifdef __MPeriodDebug
            NbSamples = NbCapSamples    '/ Copy the "NbCapSamples" variable because it is a local variable. 
            $endif
            Capture = _mpCaptureValue   '/ Copy the "_mpCaptureValue" variable because it is a local variable.
    
            CLL(1,9)
            '/ Print Datas
            $ifdef __MPeriodDebug
            Print At 1,1, Dec2 MyLoop," S",Dec NbSamples," C", Dec Capture
            $else
            Print At 1,1, Dec2 MyLoop," C", Dec Capture        
            $endif
    
            CLL(2,6)
            '/ Print Float.
            Print At 2,1,"FL: ", Dec2 FrequencyFlt,"Hz"
        $else      
            '/ Integer result.
            Set Oscilloscope2
            Frequency = MeasureFreq(20,FreqDecimals,2)   '/ Frequency in Integer. Minimum 20Hz, Decimals => Out, 2 decimals.
            Clear Oscilloscope2
            $ifdef __MPeriodDebug
            NbSamples = NbCapSamples    '/ Copy the "NbCapSamples" variable because it is a local variable. 
            $endif
            Capture = _mpCaptureValue   '/ Copy the "_mpCaptureValue" variable because it is a local variable.        
    
            CLL(1,9)
            '/ Print Datas
            $ifdef __MPeriodDebug
            Print At 1,1, Dec2 MyLoop," S",Dec NbSamples," C", Dec Capture
            $else
            Print At 1,1, Dec2 MyLoop," C", Dec Capture        
            $endif
    
            CLL(2,6)
            '/ Print Integers. NOTE: Print Dec? [number decimals]must be the same as command.
'            Print At 2,1,"FI: ", Dec Frequency,".", Dec1 FreqDecimals,"Hz"
            Print At 2,1,"FI: ", Dec Frequency,".", Dec2 FreqDecimals,"Hz"
'            Print At 2,1,"FI: ", Dec Frequency,".", Dec3 FreqDecimals,"Hz"
        $endif

        Inc MyLoop
        If MyLoop = 100 Then
           MyLoop = 0
        EndIf 

        DelayMS 500
    Loop
'/------------------------------------------------------------------------------
    End
        
     
